@@ -5,7 +5,7 @@
 
     Continuity command line commons.
 
-    :copyright: 2014 by Jonathan Zempel.
+    :copyright: 2015 by Jonathan Zempel.
     :license: BSD, see LICENSE for more details.
 """
 
@@ -81,11 +81,14 @@ class GitCommand(BaseCommand):
         self.branch = self.git.branch
 
         try:
-            self.execute()
-        except (ConnectionError, ServiceException):
-            puts("fatal: unable to access remote.")
-            self.exit()
-        except (KeyboardInterrupt, EOFError):
+            try:
+                self.execute()
+            except (ConnectionError, ServiceException):
+                puts("fatal: unable to access remote.")
+                self.exit()
+            except (KeyboardInterrupt, EOFError):
+                raise KeyboardInterrupt
+        except KeyboardInterrupt:
             puts()
             self.exit()
 
